#!/bin/csh

set IN = $PWD

set COMMENT = ""

while ( $#argv > 0 ) 
  if ( "$1" == "-m" ) then
    shift 
    if ( $#argv > 0 ) then 
      set COMMENT = "$1"
    else
      echo "no version comment" 
      exit 1
    endif
  endif
  shift
end

if ( "$COMMENT" == "" ) then 
   echo "no version comment" 
   exit 1
endif



if ( -e version.dat ) then 
    set VERSION = `cat version.dat`
    echo old version $VERSION
    set NEWVERSION    = `increment -t $VERSION`
    set NEWSVNVERSION = `increment -s $VERSION`
    echo new version $NEWVERSION
    echo $NEWVERSION > version.dat
else 
  if ( -e configure.ac ) then 
    set VERSION = `grep AC_INIT configure.ac | sed 's/.*,\(.*\),.*@.*/\1/'`
    echo old version $VERSION
    set NEWVERSION    = `increment -t $VERSION`
    set NEWSVNVERSION = `increment -s $VERSION`
    echo new version $NEWVERSION
    cp    configure.ac{,-}
    cat   configure.ac- | sed "s/$VERSION/$NEWVERSION/" > configure.ac
    diff  configure.ac{,-}
    autoreconf --force
    if ( $status != 0 ) then 
      echo "autoreconf failed"
      cd $IN
      exit
    endif
  else
    echo "no version information"
    cd $IN
    exit
  endif
endif
    
if ( -e README ) then 
   cp   README{,-}
   cat  README-   | sed "s/$VERSION/$NEWVERSION/" > README
endif



# now commit the version with the new version number

svn commit -m "$COMMENT"
if ( $status != 0 ) then 
      echo "svn commit failed"
      cd $IN
      exit 1
endif

cd $IN





